@@ -114,7 +114,8 @@ class CrudViewSerializer(serializers.ModelSerializer):
             prop.key: {
                 "title": obj.layer.get_property_title(prop.key),
                 "selected": True if prop.key in default_list else False,
-                "type": obj.layer.get_property_type(prop.key)
+                "type": obj.layer.get_property_type(prop.key),
+                "table_order": prop.table_order
             }
             for prop in obj.list_available_properties.all()
         }
@@ -293,6 +294,16 @@ class CrudFeatureDetailSerializer(BaseUpdatableMixin, FeatureSerializer):
                                                                                             {}))
         return feature
 
+    def get_update_fields(self, instance, validated_data):
+        geom = validated_data.get("geom")
+        properties = validated_data.get("properties")
+        update_fields = []
+        if geom and geom != instance.geom:
+            update_fields.append('geom')
+        if properties and properties != instance.properties:
+            update_fields.append('properties')
+        return update_fields
+
     def update(self, instance, validated_data):
         route_description = validated_data.pop('routing_information', {})
 
@@ -300,9 +311,10 @@ class CrudFeatureDetailSerializer(BaseUpdatableMixin, FeatureSerializer):
                                                             defaults={'route_description': route_description.get(
                                                                 'route_description',
                                                                 {})})
+        update_fields = self.get_update_fields(instance, validated_data)
         for key in validated_data:
             setattr(instance, key, validated_data[key])
-        instance.save()
+        instance.save(update_fields=update_fields)
         return instance
 
     def get_relations(self, obj):
@@ -447,9 +459,12 @@ class CrudFeatureDetailSerializer(BaseUpdatableMixin, FeatureSerializer):
         return data
 
     def save(self, **kwargs):
+        old_properties = {}
+        if self.instance and self.instance.pk:
+            old_properties = self.instance.properties
         super().save(**kwargs)
         # save base64 file content to storage
-        store_feature_files(self.instance)
+        store_feature_files(self.instance, old_properties)
 
     def to_representation(self, instance):
         data = super().to_representation(instance)
