@@ -11,7 +11,8 @@ from django.contrib.gis.geos import GeometryCollection, Point
 from geostore.models import LayerExtraGeom
 from geostore.settings import INTERNAL_GEOMETRY_SRID
 from mapbox_baselayer.models import MapBaseLayer
-from template_engines.templatetags.odt_tags import ImageLoaderNodeURL
+from template_engines.templatetags.odt_tags import ImageLoaderURLNode as ODTImageUrlNode
+from template_engines.templatetags.pdf_tags import ImageLoaderURLNode as PDFImageUrlNode
 from template_engines.templatetags.utils import parse_tag
 
 from terra_geocrud import settings as app_settings
@@ -22,7 +23,7 @@ logger = logging.getLogger(__name__)
 register = template.Library()
 
 
-class MapImageLoaderNodeURL(ImageLoaderNodeURL):
+class MapImageLoaderBase:
     def get_data(self, context):
         final_data = self.data
 
@@ -80,11 +81,10 @@ class MapImageLoaderNodeURL(ImageLoaderNodeURL):
         return math.floor(min(zoom_width, zoom_height))
 
     def get_value_context(self, context):
-        final_anchor = "paragraph" if not self.anchor else self.anchor.resolve(context)
         final_url = self.url
         final_request = self.request
         final_data = self.get_data(context)
-        return final_url, final_request, None, None, final_anchor, final_data
+        return final_url, final_request, None, None, final_data
 
     def get_style_base_layer(self, base_layer):
         try:
@@ -139,6 +139,28 @@ class MapImageLoaderNodeURL(ImageLoaderNodeURL):
         return style_map
 
 
+class MapImageLoaderURLODTNode(MapImageLoaderBase, ODTImageUrlNode):
+    def get_value_context(self, context):
+        """ Consider anchor as specific context for odt """
+        final_url, final_request, x, y, final_data = super().get_value_context(context)
+        final_anchor = "paragraph" if not self.anchor else self.anchor.resolve(context)
+        return final_url, final_request, x, y, final_anchor, final_data
+
+
+class MapImageLoaderURLPDFNode(MapImageLoaderBase, PDFImageUrlNode):
+    pass
+
+
+def get_map_data(kwargs):
+    return {
+        'feature_included': kwargs.pop('feature_included', None),
+        'extra_features': kwargs.pop('extra_features', None),
+        'width': kwargs.pop('width', None),
+        'height': kwargs.pop('height', None),
+        'base_layer': kwargs.pop('base_layer', None)
+    }
+
+
 @register.tag
 def map_image_url_loader(parser, token):
     """
@@ -157,12 +179,29 @@ def map_image_url_loader(parser, token):
                        'extra_features', 'anchor', 'base_layer'] for key in kwargs.keys()):
         raise template.TemplateSyntaxError("Usage: %s" % usage)
     kwargs['request'] = 'POST'
-    kwargs['data'] = {'feature_included': kwargs.pop('feature_included', None),
-                      'extra_features': kwargs.pop('extra_features', None),
-                      'width': kwargs.pop('width', None),
-                      'height': kwargs.pop('height', None),
-                      'base_layer': kwargs.pop('base_layer', None)}
-    return MapImageLoaderNodeURL(f"{app_settings.TERRA_GEOCRUD['MBGLRENDERER_URL']}/render", **kwargs)
+    kwargs['data'] = get_map_data(kwargs)
+    return MapImageLoaderURLODTNode(f"{app_settings.TERRA_GEOCRUD['MBGLRENDERER_URL']}/render", **kwargs)
+
+
+@register.tag
+def image_base64_from_url(parser, token):
+    """
+    Replace a tag by the map generated by mbglrenderer.
+    Optional keys : data, max_width, max_height, request
+    - feature_included : Primary feature will be shown
+    - extra_features : List of the extra feature you wan to add on your map
+    - width : Width of the picture rendered
+    - height : Height of the picture rendered
+    """
+    tag_name, args, kwargs = parse_tag(token, parser)
+    usage = '{{% {tag_name} width="5000" height="5000" feature_included=False extra_features="feature_1" ' \
+            'base_layer="mapbaselayer_1" %}}'.format(tag_name=tag_name)
+    if not all(key in ['width', 'height', 'feature_included',
+                       'extra_features', 'base_layer'] for key in kwargs.keys()):
+        raise template.TemplateSyntaxError("Usage: %s" % usage)
+    kwargs['request'] = 'POST'
+    kwargs['data'] = get_map_data(kwargs)
+    return MapImageLoaderURLPDFNode(f"{app_settings.TERRA_GEOCRUD['MBGLRENDERER_URL']}/render", **kwargs)
 
 
 @register.filter
@@ -178,3 +217,14 @@ def stored_image_base64(value):
         file_b64 = base64.encodebytes(file_bytes)
         result = f"{data_type};base64," + file_b64.decode()
         return result
+
+
+@register.filter
+def get_pictogram_url_for_value(feature, property_key):
+    property = feature.layer.crud_view.properties.get(key=property_key)
+    value = feature.properties.get(property_key)
+    if value:
+        instance = property.values.get(value=value)
+        if instance and instance.pictogram:
+            return instance.pictogram.url
+    return ""
